maputil

package
v0.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 31, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Overview

Copyright 2026 YLD Limited SPDX-License-Identifier: Apache-2.0 Package maputil provides generic map helper functions including type-safe conversion from any-typed maps to string-keyed maps and deterministic key iteration via sorted keys.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SortedKeys

func SortedKeys[T any](mapping map[string]T) []string

SortedKeys returns the keys of mapping in sorted order.

func ToStringAnyMap

func ToStringAnyMap(value any) (map[string]any, bool)

ToStringAnyMap converts a map[string]any or map[any]any value to map[string]any.

Types

This section is empty.

Jump to