test

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 13, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Copyright 2026 YLD Limited SPDX-License-Identifier: Apache-2.0 Package test provides shared test doubles for use across package test suites.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func MockProvider

func MockProvider(t *testing.T, writer io.Writer) *mockProvider

MockProvider returns a mock provider for use in tests.

Types

type HclBody

type HclBody struct{}

HclBody is a stub type satisfying the Updater interface for HCL test fixtures.

func (HclBody) Update

func (h HclBody) Update(filename string)

Update is a no-op implementation used by HCL fixture tests.

type YamlBody

type YamlBody struct {
	Name string `yaml:"name,omitempty"`
}

YamlBody is a stub type satisfying the Updater interface for YAML test fixtures.

func (YamlBody) Update

func (y YamlBody) Update(filename string)

Update is a no-op implementation used by YAML fixture tests.

Jump to