Documentation
¶
Overview ¶
Copyright 2026 YLD Limited SPDX-License-Identifier: Apache-2.0 Package maputil provides generic map helper functions including type-safe conversion from any-typed maps to string-keyed maps and deterministic key iteration via sorted keys.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SortedKeys ¶
SortedKeys returns the keys of mapping in sorted order.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.