package
Version:
v0.0.6
Opens a new window with list of versions in this module.
Published: Mar 12, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Copyright 2026 YLD Limited
SPDX-License-Identifier: Apache-2.0
Package test provides shared test doubles for use across package test suites.
MockProvider returns a mock provider for use in tests.
HclBody is a stub type satisfying the Updater interface for HCL test fixtures.
func (HclBody) Update ¶
Update is a no-op implementation used by HCL fixture tests.
type YamlBody struct {
Name string `yaml:"name,omitempty"`
}
YamlBody is a stub type satisfying the Updater interface for YAML test fixtures.
func (YamlBody) Update ¶
Update is a no-op implementation used by YAML fixture tests.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.