Documentation
¶
Overview ¶
Copyright 2026 YLD Limited SPDX-License-Identifier: Apache-2.0 Package step contains the Step domain model and bidirectional serialization logic. StepConfig represents the HCL-side structure decoded via gohcl, while Step holds the normalized intermediate representation used for both HCL-to-YAML parsing and YAML-to-HCL unparsing.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Step ¶
type Step struct {
Identifier string `yaml:"-"`
Id cty.Value `yaml:"id,omitempty" hcl:"id"`
If cty.Value `yaml:"if,omitempty" hcl:"if"`
Name cty.Value `yaml:"name,omitempty" hcl:"name"`
Uses cty.Value `yaml:"uses,omitempty" hcl:"uses"`
UsesComment string `yaml:"-"`
Run cty.Value `yaml:"run,omitempty" hcl:"run"`
WorkingDirectory cty.Value `yaml:"working-directory,omitempty" hcl:"working_directory"`
Shell cty.Value `yaml:"shell,omitempty" hcl:"shell"`
With cty.Value `yaml:"with,omitempty" hcl:"with"`
Env cty.Value `yaml:"env,omitempty" hcl:"env"`
ContinueOnError cty.Value `yaml:"continue-on-error,omitempty" hcl:"continue_on_error"`
TimeoutMinutes cty.Value `yaml:"timeout-minutes,omitempty" hcl:"timeout_minutes"`
}
Step holds the parsed fields of a single GitHub Actions workflow step.
type StepConfig ¶
type StepConfig struct {
Identifier string `hcl:"id,label"`
Id hcl.Expression `hcl:"id,attr"`
IgnoreId hcl.Expression `hcl:"ignore_id,attr"`
If hcl.Expression `hcl:"if,attr"`
Name hcl.Expression `hcl:"name,attr"`
Uses action.UsesListConfig `hcl:"uses,block"`
Run hcl.Expression `hcl:"run,attr"`
WorkingDirectory hcl.Expression `hcl:"working_directory,attr"`
Shell hcl.Expression `hcl:"shell,attr"`
With action.WithListConfig `hcl:"with,block"`
Env action.EnvListConfig `hcl:"env,block"`
ContinueOnError hcl.Expression `hcl:"continue_on_error,attr"`
TimeoutMinutes hcl.Expression `hcl:"timeout_minutes,attr"`
}
StepConfig represents the HCL configuration for a single step block.
type StepListConfig ¶
type StepListConfig []StepConfig
StepListConfig is a slice of StepConfig decoded from HCL step blocks.
Click to show internal directories.
Click to hide internal directories.